@@ -13,7 +13,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, overload
+from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_resource_groups.paginator import (
     ListGroupResourcesPaginator,
@@ -48,26 +48,26 @@ __all__ = ("ResourceGroupsClient",)
 
 
 class Exceptions:
-    BadRequestException: Boto3ClientError
-    ClientError: Boto3ClientError
-    ForbiddenException: Boto3ClientError
-    InternalServerErrorException: Boto3ClientError
-    MethodNotAllowedException: Boto3ClientError
-    NotFoundException: Boto3ClientError
-    TooManyRequestsException: Boto3ClientError
-    UnauthorizedException: Boto3ClientError
+    BadRequestException: Type[Boto3ClientError]
+    ClientError: Type[Boto3ClientError]
+    ForbiddenException: Type[Boto3ClientError]
+    InternalServerErrorException: Type[Boto3ClientError]
+    MethodNotAllowedException: Type[Boto3ClientError]
+    NotFoundException: Type[Boto3ClientError]
+    TooManyRequestsException: Type[Boto3ClientError]
+    UnauthorizedException: Type[Boto3ClientError]
 
 
 class ResourceGroupsClient:
     """
-    [ResourceGroups.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/resource-groups.html#ResourceGroups.Client)
+    [ResourceGroups.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/resource-groups.html#ResourceGroups.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/resource-groups.html#ResourceGroups.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/resource-groups.html#ResourceGroups.Client.can_paginate)
         """
 
     def create_group(
@@ -78,12 +78,12 @@ class ResourceGroupsClient:
         Tags: Dict[str, str] = None,
     ) -> CreateGroupOutputTypeDef:
         """
-        [Client.create_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/resource-groups.html#ResourceGroups.Client.create_group)
+        [Client.create_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/resource-groups.html#ResourceGroups.Client.create_group)
         """
 
     def delete_group(self, GroupName: str) -> DeleteGroupOutputTypeDef:
         """
-        [Client.delete_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/resource-groups.html#ResourceGroups.Client.delete_group)
+        [Client.delete_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/resource-groups.html#ResourceGroups.Client.delete_group)
         """
 
     def generate_presigned_url(
@@ -94,22 +94,22 @@ class ResourceGroupsClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/resource-groups.html#ResourceGroups.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/resource-groups.html#ResourceGroups.Client.generate_presigned_url)
         """
 
     def get_group(self, GroupName: str) -> GetGroupOutputTypeDef:
         """
-        [Client.get_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/resource-groups.html#ResourceGroups.Client.get_group)
+        [Client.get_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/resource-groups.html#ResourceGroups.Client.get_group)
         """
 
     def get_group_query(self, GroupName: str) -> GetGroupQueryOutputTypeDef:
         """
-        [Client.get_group_query documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/resource-groups.html#ResourceGroups.Client.get_group_query)
+        [Client.get_group_query documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/resource-groups.html#ResourceGroups.Client.get_group_query)
         """
 
     def get_tags(self, Arn: str) -> GetTagsOutputTypeDef:
         """
-        [Client.get_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/resource-groups.html#ResourceGroups.Client.get_tags)
+        [Client.get_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/resource-groups.html#ResourceGroups.Client.get_tags)
         """
 
     def list_group_resources(
@@ -120,7 +120,7 @@ class ResourceGroupsClient:
         NextToken: str = None,
     ) -> ListGroupResourcesOutputTypeDef:
         """
-        [Client.list_group_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/resource-groups.html#ResourceGroups.Client.list_group_resources)
+        [Client.list_group_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/resource-groups.html#ResourceGroups.Client.list_group_resources)
         """
 
     def list_groups(
@@ -130,36 +130,36 @@ class ResourceGroupsClient:
         NextToken: str = None,
     ) -> ListGroupsOutputTypeDef:
         """
-        [Client.list_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/resource-groups.html#ResourceGroups.Client.list_groups)
+        [Client.list_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/resource-groups.html#ResourceGroups.Client.list_groups)
         """
 
     def search_resources(
         self, ResourceQuery: ResourceQueryTypeDef, MaxResults: int = None, NextToken: str = None
     ) -> SearchResourcesOutputTypeDef:
         """
-        [Client.search_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/resource-groups.html#ResourceGroups.Client.search_resources)
+        [Client.search_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/resource-groups.html#ResourceGroups.Client.search_resources)
         """
 
     def tag(self, Arn: str, Tags: Dict[str, str]) -> TagOutputTypeDef:
         """
-        [Client.tag documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/resource-groups.html#ResourceGroups.Client.tag)
+        [Client.tag documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/resource-groups.html#ResourceGroups.Client.tag)
         """
 
     def untag(self, Arn: str, Keys: List[str]) -> UntagOutputTypeDef:
         """
-        [Client.untag documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/resource-groups.html#ResourceGroups.Client.untag)
+        [Client.untag documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/resource-groups.html#ResourceGroups.Client.untag)
         """
 
     def update_group(self, GroupName: str, Description: str = None) -> UpdateGroupOutputTypeDef:
         """
-        [Client.update_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/resource-groups.html#ResourceGroups.Client.update_group)
+        [Client.update_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/resource-groups.html#ResourceGroups.Client.update_group)
         """
 
     def update_group_query(
         self, GroupName: str, ResourceQuery: ResourceQueryTypeDef
     ) -> UpdateGroupQueryOutputTypeDef:
         """
-        [Client.update_group_query documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/resource-groups.html#ResourceGroups.Client.update_group_query)
+        [Client.update_group_query documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/resource-groups.html#ResourceGroups.Client.update_group_query)
         """
 
     @overload
@@ -167,13 +167,13 @@ class ResourceGroupsClient:
         self, operation_name: Literal["list_group_resources"]
     ) -> ListGroupResourcesPaginator:
         """
-        [Paginator.ListGroupResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroupResources)
+        [Paginator.ListGroupResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroupResources)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_groups"]) -> ListGroupsPaginator:
         """
-        [Paginator.ListGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroups)
+        [Paginator.ListGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroups)
         """
 
     @overload
@@ -181,5 +181,5 @@ class ResourceGroupsClient:
         self, operation_name: Literal["search_resources"]
     ) -> SearchResourcesPaginator:
         """
-        [Paginator.SearchResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/resource-groups.html#ResourceGroups.Paginator.SearchResources)
+        [Paginator.SearchResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/resource-groups.html#ResourceGroups.Paginator.SearchResources)
         """
